/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.plugins.pmd;

import org.sonar.plugins.api.Extension;
import org.sonar.plugins.api.Plugin;
import org.sonar.plugins.pmd.cpd.CpdMavenCollector;
import org.sonar.plugins.pmd.cpd.DuplicatedLinesJob;
import org.sonar.plugins.pmd.cpd.DuplicatedLinesRatioJob;

import java.util.ArrayList;
import java.util.List;

public class PmdPlugin implements Plugin {

  public static final String KEY = "pmd";

  public String getKey() {
    return KEY;
  }

  public String getName() {
    return "PMD";
  }

  public String getDescription() {
    return "Coding rules from <a href='http://pmd.sourceforge.net'>PMD</a>.";
  }

  public List<Class<? extends Extension>> getExtensions() {
    List<Class<? extends Extension>> list = new ArrayList<Class<? extends Extension>>();

    // maven collectors
    list.add(CpdMavenCollector.class);
    list.add(PmdMavenCollector.class);

    // coding rules
    list.add(PmdRulesRepository.class);

    // jobs
    list.add(DuplicatedLinesJob.class);
    list.add(DuplicatedLinesRatioJob.class);
    return list;
  }
}
